Module: ActionDispatch::Routing::Mapper::Base
- Defined in:
- lib/brick/extensions.rb
Instance Method Summary collapse
-
#mount_brick_routes ⇒ Object
Pro-actively assess Brick routes.
Instance Method Details
#mount_brick_routes ⇒ Object
Pro-actively assess Brick routes. Useful when there is a "catch all" wildcard route
at the end of an existing routes.rb file, which would normally steal the show and
not let Brick have any fun. So just call this right before any wildcard routes, and
you'll be in business!
1394 1395 1396 |
# File 'lib/brick/extensions.rb', line 1394 def mount_brick_routes add_brick_routes if !::Brick.routes_done && respond_to?(:add_brick_routes) end |