Module: ActionDispatch::Routing::Mapper::Base

Defined in:
lib/brick/extensions.rb

Instance Method Summary collapse

Instance Method Details

#mount_brick_routesObject

Pro-actively assess Brick routes. Useful when there is a “catch all” wildcard route at the end of an existing routes.rb file, which would normally steal the show and not let Brick have any fun. So just call this right before any wildcard routes, and you’ll be in business!



1332
1333
1334
# File 'lib/brick/extensions.rb', line 1332

def mount_brick_routes
  add_brick_routes if !::Brick.routes_done && respond_to?(:add_brick_routes)
end